LlamaModelConfig class final

Constructors

LlamaModelConfig({required String modelPath, int? contextSize, int? gpuLayerCount, String? mmprojPath, bool mmprojUseGpu = false, int? imageMinTokens, int? imageMaxTokens})
const

Properties

contextSize int?
final
gpuLayerCount int?
final
hashCode int
The hash code for this object.
no setterinherited
imageMaxTokens int?
final
imageMinTokens int?
final
mmprojPath String?
final
mmprojUseGpu bool
final
modelPath String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited