LlamaResponseRequiresAction class final

Inheritance

Constructors

LlamaResponseRequiresAction({required LlamaResponseObject response, required List<LlamaToolCall> toolCalls})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
response LlamaResponseObject
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolCalls List<LlamaToolCall>
final
type String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited