LlamaServerClient class final

Constructors

LlamaServerClient({required Uri baseUri, String? apiKey})

Properties

apiKey String?
final
baseUri Uri
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createChatCompletion({required String model, required List<Map<String, Object?>> messages, int? maxTokens, double? temperature, double? topP, List<String> stop = const []}) Future<Map<String, Object?>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
streamChatCompletion({required String model, required List<Map<String, Object?>> messages, int? maxTokens, double? temperature, double? topP, List<String> stop = const []}) Stream<Map<String, Object?>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited