LlcsEngineBackend class final
- Implemented types
Constructors
- LlcsEngineBackend(LlcsEngine engine, {Duration pollTimeout = const Duration(milliseconds: 100)})
Properties
- engine → LlcsEngine
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pollTimeout → Duration
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
caps(
) → Map< String, Object?> -
override
-
close(
) → void -
override
-
complete(
Map< String, Object?> request) → Stream<Map< String, Object?> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited